@@ -24,6 +24,7 @@
 # 2015-09-04: throw error if there are too few colors for groups (fixing bug reported by Ottorino Pantani). J. Fox
 # 2016-02-16: replace cov.trob() call with MASS::cov.trob(). J. Fox
 # 2017-11-30: substitute carPalette() for palette(). J. Fox
+# 2022-09-22: add grid argument. J. Fox
 
 ellipse <- function(center, shape, radius, log="", center.pch=19, center.cex=1.5, segments=51, draw=TRUE, add=draw, 
 		xlab="", ylab="", col=carPalette()[2], lwd=2, fill=FALSE, fill.alpha=0.3,
@@ -221,10 +222,9 @@ confidenceEllipse <- function (model, ...) {
 	UseMethod("confidenceEllipse")
 }
 
-
 confidenceEllipse.lm <- function(model, which.coef, vcov.=vcov, L, levels=0.95, Scheffe=FALSE, dfn,
 		center.pch=19, center.cex=1.5, segments=51, xlab, ylab, 
-		col=carPalette()[2], lwd=2, fill=FALSE, fill.alpha=0.3, draw=TRUE, add=!draw, ...){
+		col=carPalette()[2], lwd=2, fill=FALSE, fill.alpha=0.3, draw=TRUE, add=!draw, grid=TRUE, ...){
 	if (missing(dfn)) dfn <- if (Scheffe) sum(df.terms(model)) else 2
 	dfd <- df.residual(model)
 	vcov. <- getVcov(vcov., model)
@@ -256,7 +256,7 @@ confidenceEllipse.lm <- function(model, which.coef, vcov.=vcov, L, levels=0.95,
 		add.plot <- !level==max(levels) | add
 		result[[i]] <- ellipse(coef, shape, radius, add=add.plot, xlab=xlab, ylab=ylab,
 				center.pch=center.pch, center.cex=center.cex, segments=segments, 
-				col=col, lwd=lwd, fill=fill, fill.alpha=fill.alpha, draw=draw, ...)
+				col=col, lwd=lwd, fill=fill, fill.alpha=fill.alpha, draw=draw, grid=grid, ...)
 	}
 	invisible(if (length(levels) == 1) result[[1]] else result)
 }
@@ -264,7 +264,7 @@ confidenceEllipse.lm <- function(model, which.coef, vcov.=vcov, L, levels=0.95,
 
 confidenceEllipse.default <- function(model, which.coef, vcov.=vcov, L, levels=0.95, Scheffe=FALSE, dfn,
 		center.pch=19, center.cex=1.5, segments=51, xlab, ylab,
-		col=carPalette()[2], lwd=2, fill=FALSE, fill.alpha=0.3, draw=TRUE, add=!draw, ...){
+		col=carPalette()[2], lwd=2, fill=FALSE, fill.alpha=0.3, draw=TRUE, add=!draw, grid=TRUE, ...){
   vcov. <- getVcov(vcov., model)  
 #if (is.function(vcov.)) vcov. <- vcov.(model)
 	if (missing(L)){
@@ -297,7 +297,7 @@ confidenceEllipse.default <- function(model, which.coef, vcov.=vcov, L, levels=0
 		add.plot <- !level==max(levels) | add
 		result[[i]] <- ellipse(coef, shape, radius, add=add.plot, xlab=xlab, ylab=ylab,
 				center.pch=center.pch, center.cex=center.cex, segments=segments,
-				col=col, lwd=lwd, fill=fill, fill.alpha=fill.alpha, draw=draw, ...)
+				col=col, lwd=lwd, fill=fill, fill.alpha=fill.alpha, draw=draw, grid=grid, ...)
 	}
 	invisible(if (length(levels) == 1) result[[1]] else result)
 }
@@ -325,3 +325,109 @@ makeLinearCombinations <- function(L, coef, V){
 	ylab <- names(coef)[2]
 	list(coef=coef, shape=shape, xlab=xlab, ylab=ylab)
 }
+
+confidenceEllipses <- function(model, ...) {
+  UseMethod("confidenceEllipses")
+}
+
+confidenceEllipses.default <- function(model, coefnames,  main, grid=TRUE, ...) {
+    if (missing(main))
+      main <- paste("Pairwise Confidence Ellipses for",
+                    deparse(substitute(model)))
+    b <- coef(model)
+    p <- length(b)
+    if (missing(coefnames))
+      coefnames <- paste0(names(b), "\ncoefficient")
+    save <-
+      par(
+        mfrow = c(p, p),
+        mar = c(2, 2, 0, 0) + 0.1,
+        oma = c(0, 0, 2, 0) + 0.2
+      )
+    on.exit(par(save))
+    ylab <- coefnames[1]
+    for (i in 1:p) {
+      for (j in 1:p) {
+        if (j == 1) {
+          yaxis <- TRUE
+        } else {
+          yaxis <- FALSE
+        }
+        if (i == p) {
+          xaxis <- TRUE
+        } else {
+          xaxis <- FALSE
+        }
+        if (i == j) {
+          if (i == 1) {
+            confidenceEllipse(
+              model,
+              c(2, 1),
+              xaxt = "n",
+              yaxt = "n",
+              center.pch = "",
+              col = "white",
+              grid = FALSE
+            )
+            axis(2)
+          } else if (j == p) {
+            confidenceEllipse(
+              model,
+              c(p, 2),
+              xaxt = "n",
+              yaxt = "n",
+              center.pch = "",
+              col = "white",
+              grid = FALSE
+            )
+            axis(1)
+          }
+          else {
+            confidenceEllipse(
+              model,
+              c(1, 2),
+              xaxt = "n",
+              yaxt = "n",
+              center.pch = "",
+              col = "white",
+              grid = FALSE
+            )
+          }
+          usr <- par("usr")
+          text(mean(usr[1:2]), mean(usr[3:4]), coefnames[i])
+        }
+        else{
+          confidenceEllipse(model, c(j, i), # xlab = xlab, ylab = ylab,
+                            xaxt = "n", yaxt = "n", grid=grid, ...)
+          if (j == 1)
+            axis(2)
+          if (i == p)
+            axis(1)
+        }
+      }
+    }
+    title(main = main,
+          outer = TRUE,
+          line = 1)
+    invisible(NULL)
+}
+
+confidenceEllipse.mlm <- function(model, xlab, ylab, which.coef=1:2, ...){
+  if (missing(xlab) || missing(ylab)){
+    coefnames <- rownames(vcov(model))
+    if (missing(xlab)) xlab <- coefnames[which.coef[1]]
+    if (missing(ylab)) ylab <- coefnames[which.coef[2]]
+  }
+  NextMethod(xlab=xlab, ylab=ylab)
+}
+
+confidenceEllipses.mlm <- function(model, coefnames, main, ...) {
+  if (missing(coefnames))  {
+    coefnames <- rownames(vcov(model))
+    coefnames <- paste0(coefnames, "\ncoefficient")
+  }
+  if (missing(main))
+    main <- paste("Pairwise Confidence Ellipses for",
+                           deparse(substitute(model)))
+  NextMethod(coefnames = coefnames, main = main)
+}
